package com.qmth.teachcloud.report.business.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.google.common.reflect.TypeToken;
import com.google.gson.Gson;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.util.ExcelUtil;
import com.qmth.teachcloud.common.util.JacksonUtil;
import com.qmth.teachcloud.common.util.ServletUtil;
import com.qmth.teachcloud.report.business.bean.dto.excel.TAExamCourseDto;
import com.qmth.teachcloud.report.business.entity.TAExamCourse;
import com.qmth.teachcloud.report.business.entity.TAExamTotal;
import com.qmth.teachcloud.report.business.enums.SemesterEnum;
import com.qmth.teachcloud.report.business.mapper.TAExamTotalMapper;
import com.qmth.teachcloud.report.business.service.TAExamTotalService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;
import java.util.Objects;

/**
 * <p>
 * 考试维度总计 服务实现类
 * </p>
 *
 * @author wangliang
 * @since 2021-06-01
 */
@Service
public class TAExamTotalServiceImpl extends ServiceImpl<TAExamTotalMapper, TAExamTotal> implements TAExamTotalService {

    @Resource
    TAExamTotalMapper taExamTotalMapper;

    @Resource
    TAExamTotalService taExamTotalService;

    @Override
    public TAExamTotal getOverview(SemesterEnum semester, Long examId) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        return taExamTotalMapper.getOverview(schoolId, Objects.nonNull(semester) ? semester.name() : null, examId);
    }

    @Override
    public IPage<TAExamCourse> getCourseSummary(SemesterEnum semester, Long examId, Integer pageNumber, Integer pageSize) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        Page<TAExamCourse> page = new Page<>(pageNumber, pageSize);
        IPage<TAExamCourse> listPage = taExamTotalMapper.getCourseSummary(page, schoolId, Objects.nonNull(semester) ? semester.name() : null, examId);
        return listPage;
    }

    @Override
    public void exportCourseSummary(SemesterEnum semester, Long examId, HttpServletResponse response) throws Exception {
        IPage<TAExamCourse> taExamCourseIPage = taExamTotalService.getCourseSummary(semester, examId, SystemConstant.PAGE_NUMBER, SystemConstant.PAGE_SIZE);
        Gson gson = new Gson();
        List<TAExamCourseDto> examStudentCourseDtoList = gson.fromJson(JacksonUtil.parseJson(taExamCourseIPage.getRecords()), new TypeToken<List<TAExamCourseDto>>() {
        }.getType());
        ExcelUtil.excelExport("课程分析", TAExamCourseDto.class, examStudentCourseDtoList, response);
    }

    @Override
    public void exportDataAnalysis(SemesterEnum semester, Long examId, String courseCode, HttpServletResponse response) {

    }
}
